summaryrefslogtreecommitdiffstats
path: root/src/H5Eproto.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Eproto.h')
-rw-r--r--src/H5Eproto.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/H5Eproto.h b/src/H5Eproto.h
index c61704c..cd3f58a 100644
--- a/src/H5Eproto.h
+++ b/src/H5Eproto.h
@@ -142,7 +142,8 @@ typedef enum
H5E_BADMESG, /* Unrecognized message */
/* Directory related errors */
- H5E_COMPLEN /* Name component is too long */
+ H5E_COMPLEN, /* Name component is too long */
+ H5E_LINK /* Link count failure */
}
hdf_min_err_code_t;